==> libgnomedb3_3.0.0.orig.tar.gz: libgnomedb-3.0.0/libgnomedb-extra/gnome-db-report-editor.h <==
/* GNOME DB library
 * Copyright (C) 1999-2002 The GNOME Foundation.
 *
 * AUTHORS:
 *      Rodrigo Moya <rodrigo@gnome-db.org>
 *
 * This Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#if !defined(__gnome_db_report_editor_h__)
#  define __gnome_db_report_editor_h__

#include <gtk/gtkvbox.h>

G_BEGIN_DECLS

#define GNOME_DB_TYPE_REPORT_EDITOR            (gnome_db_report_editor_get_type())
#define GNOME_DB_REPORT_EDITOR(obj)            (G_TYPE_CHECK_INSTANCE_CAST (obj, GNOME_DB_TYPE_REPORT_EDITOR, GnomeDbReportEditor))
#define GNOME_DB_REPORT_EDITOR_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST (klass, GNOME_DB_TYPE_REPORT_EDITOR, GnomeDbReportEditorClass))
#define GNOME_DB_IS_REPORT_EDITOR(obj)         (G_TYPE_CHECK_INSTANCE_TYPE (obj, GNOME_DB_TYPE_REPORT_EDITOR))
#define GNOME_DB_IS_REPORT_EDITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_DB_TYPE_REPORT_EDITOR))

typedef struct _GnomeDbReportEditor        GnomeDbReportEditor;
typedef struct _GnomeDbReportEditorClass   GnomeDbReportEditorClass;
typedef struct _GnomeDbReportEditorPrivate GnomeDbReportEditorPrivate;

struct _GnomeDbReportEditor {
	GtkVBox box;
	GnomeDbReportEditorPrivate *priv;
};

struct _GnomeDbReportEditorClass {
	GtkVBoxClass parent_class;
};

GType      gnome_db_report_editor_get_type (void);
GtkWidget *gnome_db_report_editor_new (void);

G_END_DECLS

#endif

==> libgnomedb-3.99.5.tar.gz: libgnomedb-3.99.5/libgnomedb-extra/gnome-db-report-editor.h <==
/* GNOME DB library
 * Copyright (C) 1999-2002 The GNOME Foundation.
 *
 * AUTHORS:
 *      Rodrigo Moya <rodrigo@gnome-db.org>
 *
 * This Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#if !defined(__gnome_db_report_editor_h__)
#  define __gnome_db_report_editor_h__

#include <gtk/gtkvbox.h>

G_BEGIN_DECLS

#define GNOME_DB_TYPE_REPORT_EDITOR            (gnome_db_report_editor_get_type())
#define GNOME_DB_REPORT_EDITOR(obj)            (G_TYPE_CHECK_INSTANCE_CAST (obj, GNOME_DB_TYPE_REPORT_EDITOR, GnomeDbReportEditor))
#define GNOME_DB_REPORT_EDITOR_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST (klass, GNOME_DB_TYPE_REPORT_EDITOR, GnomeDbReportEditorClass))
#define GNOME_DB_IS_REPORT_EDITOR(obj)         (G_TYPE_CHECK_INSTANCE_TYPE (obj, GNOME_DB_TYPE_REPORT_EDITOR))
#define GNOME_DB_IS_REPORT_EDITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_DB_TYPE_REPORT_EDITOR))

typedef struct _GnomeDbReportEditor        GnomeDbReportEditor;
typedef struct _GnomeDbReportEditorClass   GnomeDbReportEditorClass;
typedef struct _GnomeDbReportEditorPrivate GnomeDbReportEditorPrivate;

struct _GnomeDbReportEditor {
	GtkVBox box;
	GnomeDbReportEditorPrivate *priv;
};

struct _GnomeDbReportEditorClass {
	GtkVBoxClass parent_class;
};

GType      gnome_db_report_editor_get_type (void) G_GNUC_CONST;
GtkWidget *gnome_db_report_editor_new (void);

G_END_DECLS

#endif
